@@ -56,11 +56,9 @@ class PhotonOdometry:
 
         field_to_robot = (
             field_to_camera[0] - h * math.sin(theta),
-            field_to_camera[1] - h * math.cos(theta)
+            field_to_camera[1] + h * math.cos(theta)
         )
 
-        self.pose = field_to_robot
-
         return field_to_robot
 
     def parse_field_layout(self, field_layout: dict):
